Builds — bodhi 3.1.0 documentation

# Builds

## Build service at /builds/{nvr}

Koji builds

### GET

Retrieve a Build by name-version-release, specified via an “nvr” query string parameter.

Args:
  request (pyramid.request): The current web request.
Returns:
  bodhi.server.models.Build or None: The Build matching the search, or None if there is no
    Build with the given NVR.

Response: json

## Builds service at /builds/

Koji builds

### GET

values in the querystring

- chrome (Boolean) - (default: true)
- page (Integer) - (default: 1)
- rows_per_page (Integer) - (default: 20)
- nvr (String) - (optional)
- packages (Sequence) - (optional)
- releases (Sequence) - (optional)
- updates (Sequence) - (optional)

Search for Builds by given criteria.

The following criteria can be provided via query string parameters to search for Builds:
  nvr: The dash-separated name-version-release of a Build. updates: A space or comma separated list of updates to limit the search by. packages: A space or comma separated list of packages to search for builds by. releases: A space or comma separated list of release ids to limit builds by. page: Which page of search results are desired. rows_per_pags: How many results per page are desired.
Args:
  request (pyramid.request): The current request, containing the search criteria documented
    above.
Returns:
  dict: A dictionary with the following key value mappings:
    builds: An iterable of builds that match the search criteria. page: The current page. pages: The total number of pages. rows_per_page: The number of rows per page. total: The number of builds that match the search criteria.

Validate the location against the schema defined on the service.

The content of the location is deserialized, validated and stored in the `request.validated` attribute.

Note

If no schema is defined, this validator does nothing.

Param request: | Current request
Type request: | `Request`
Param schema: | The Colander schema
Param deserializer:
| Optional deserializer, defaults to `cornice.validators.extract_cstruct()`

Make sure referenced releases exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced updates exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Make sure referenced packages exist.

Args:
  request (pyramid.util.Request): The current request. kwargs (dict): The kwargs of the related service definition. Unused.

Response: json